<?php
require_once ASD_APPLICATION_PATH . '/models/AbstractModel.php';

class Asd_Model_Block_Toolbar extends Asd_Model_AbstractModel
{
    protected $_categoriesContext; //Options or PostMeta model
    protected $_amazon;
    protected $_market;
    protected $_markets;
    protected $_params;

    protected $_visible = TRUE;

    public function setParams(array $params)
    {
        if (! Asd_Application::getModel('Options')->getValue('show_on_mobile_devices')
            && Asd_Application::loadLibrary('AsdPumka_MobileDetect')->isMobile()
        ) {
            $this->_visible = FALSE;
            return $this;
        }

        $this->_params = $params;

        if ('node' == $params['page_type']) {
            $meta = Asd_Application::getModel('PostMeta')
                ->setPostId($params['id']);

            if ($meta->getValue('customize_categories')) {
                $this->_categoriesContext = $meta;
            }
        }

        if (!$this->_categoriesContext) {
            $this->_categoriesContext = Asd_Application::getModel('Options');
        }

        $this->_markets = Asd_Application::getModel('Amazon_Market')
            ->getList(TRUE);

        $this->_market = isset($params['market'])
            ? $params['market']
            : $this->_categoriesContext->getValue('market');

        // Suggest market by IP
        // Auto fix default market if not supported
        $this->_market = Asd_Application::getModel('Amazon_Market')
            ->suggest($this->_market, TRUE);

        $this->_amazon = Asd_Application::getModel('Amazon')
            ->setOption('market', $this->_market);

        return $this;
    }

    //
    // Categories context
    //

    public function getMarket()
    {
        return $this->_market;
    }

    public function getCategory()
    {
        return $this->_categoriesContext->getValue("{$this->_market}_category");
    }

    public function getSubcategory()
    {
        return $this->_categoriesContext->getValue("{$this->_market}_subcategory");
    }

    //
    // Amazon categories
    //
    public function getCategories()
    {
        return $this->_amazon->getCategories();
    }

    public function getSubcategories()
    {
        $category = $this->getCategory();
        if (!$category) {
            return array();
        }

        $result = $this->_amazon->getCategories($category);

        return $result;
    }

    //
    // Amazon accessors
    //

    public function getMarketConfig()
    {
        return $this->_amazon->getMarketConfig();
    }

    //
    // Other
    //
    public function getDiscountRates()
    {
        return array(
            '' => __('0+% off', 'amazon-bar-plugin'),
            '1-20' => __('1-20% off', 'amazon-bar-plugin'),
            '21-50' => __('21-50% off', 'amazon-bar-plugin'),
            '50-' => __('50+% off', 'amazon-bar-plugin'),
        );
    }

    public function getMarkets()
    {
        return $this->_markets;
    }

    public function getParams()
    {
        return $this->_params;
    }

    public function isVisible()
    {
        return $this->_visible;
    }
}